@@ -1,11 +1,11 @@
 package Text::ANSITable;
 
-our $DATE = '2015-03-05'; # DATE
-our $VERSION = '0.40'; # VERSION
+our $DATE = '2015-08-18'; # DATE
+our $VERSION = '0.41'; # VERSION
 
 use 5.010001;
 use Carp;
-use Log::Any '$log';
+use Log::Any::IfLOG '$log';
 use Moo;
 use experimental 'smartmatch';
 
@@ -1659,7 +1659,7 @@ Text::ANSITable - Create nice formatted tables using extended ASCII and ANSI col
 
 =head1 VERSION
 
-This document describes version 0.40 of Text::ANSITable (from Perl distribution Text-ANSITable), released on 2015-03-05.
+This document describes version 0.41 of Text::ANSITable (from Perl distribution Text-ANSITable), released on 2015-08-18.
 
 =head1 SYNOPSIS
 
@@ -1682,7 +1682,7 @@ This document describes version 0.40 of Text::ANSITable (from Perl distribution
  $t->add_row(["tao kae noi", "blue"  ,   18500]);
 
  # draw it!
- say $t->draw;
+ print $t->draw;
 
 Samples of output:
 
